@@ -92,19 +92,18 @@ class LocalRunnerOptionStore(SimRunnerOptionStore):
 
 class LocalMRJobRunner(SimMRJobRunner):
     """Runs an :py:class:`~mrjob.job.MRJob` locally, for testing purposes.
+    Invoked when you run your job with ``-r local``.
 
-    This is NOT the default way of running jobs; we assume you'll spend some
-    time debugging your job before you're ready to run it on EMR or Hadoop.
+    Unlike :py:class:`~mrjob.job.InlineMRJobRunner`, this actually spawns
+    multiple subprocesses for each task.
+
+    This is fairly inefficient and *not* a substitute for Hadoop; it's
+    main purpose is to help you test out :mrjob-opt:`setup` commands.
 
     It's rare to need to instantiate this class directly (see
     :py:meth:`~LocalMRJobRunner.__init__` for details).
 
-    :py:class:`LocalMRJobRunner` adds the current working directory to the
-    subprocesses' :envvar:`PYTHONPATH`, so if you're using it to test an EMR
-    job locally, be aware that it may see more Python modules than will
-    actaully be uploaded. This behavior may change in the future.
     """
-
     alias = 'local'
 
     OPTION_STORE_CLASS = LocalRunnerOptionStore
@@ -127,7 +126,7 @@ class LocalMRJobRunner(SimMRJobRunner):
         """
         super(LocalMRJobRunner, self).__init__(**kwargs)
 
-        self._all_proc_dicts = None
+        self._all_proc_dicts = []
 
         # jobconf variables set by our own job (e.g. files "uploaded")
         #
@@ -140,8 +139,6 @@ class LocalMRJobRunner(SimMRJobRunner):
                   working_dir, env):
         step = self._get_step(step_num)
 
-        if self._all_proc_dicts is None:
-            self._all_proc_dicts = []
         if step_type == 'mapper':
             procs_args = self._mapper_arg_chain(
                 step, step_num, input_path)
@@ -157,7 +154,7 @@ class LocalMRJobRunner(SimMRJobRunner):
         for proc_dict in self._all_proc_dicts:
             self._wait_for_process(proc_dict, step_num)
 
-        self.all_proc_dicts = None
+        self._all_proc_dicts = []
 
     def _filter_if_any(self, substep_dict):
         if substep_dict['type'] == 'script':
