@@ -197,7 +197,7 @@ class RunnerOptionStore(OptionStore):
             'cleanup_on_failure': ['NONE'],
             'hadoop_version': '0.20',
             'owner': owner,
-            'sh_bin': ['sh'],
+            'sh_bin': ['sh', '-e'],
         })
 
     def _validate_cleanup(self):
@@ -713,7 +713,7 @@ class MRJobRunner(object):
 
                 if steps_proc.returncode != 0:
                     raise Exception(
-                        'error getting step information: %s', stderr)
+                        'error getting step information: \n%s' % stderr)
 
                 try:
                     steps = json.loads(stdout)
@@ -898,9 +898,7 @@ class MRJobRunner(object):
         self._working_dir_mgr.add('file', self._setup_wrapper_script_path)
 
     def _parse_setup(self):
-        """Helper for :py:meth:`_create_setup_wrapper_script`.
-
-        Parse the *setup* option with
+        """Parse the *setup* option with
         :py:func:`mrjob.setup.parse_setup_cmd()`.
 
         If *bootstrap_mrjob* and ``self.BOOTSTRAP_MRJOB_IN_SETUP`` are both
@@ -953,7 +951,7 @@ class MRJobRunner(object):
 
         writeln('# store $PWD')
         writeln('__mrjob_PWD=$PWD')
-        writeln('')
+        writeln()
 
         writeln('# obtain exclusive file lock')
         # Basically, we're going to tie file descriptor 9 to our lockfile,
@@ -968,10 +966,14 @@ class MRJobRunner(object):
         writeln()
 
         writeln('# setup commands')
+        # group setup commands so we can redirect their input/output (see
+        # below). Don't use parens; this would invoke a subshell, which would
+        # keep us from exporting environment variables to the task.
+        writeln('{')
         for cmd in setup:
             # reconstruct the command line, substituting $__mrjob_PWD/<name>
             # for path dicts
-            line = ''
+            line = '  '  # indent, since these commands are in a group
             for token in cmd:
                 if isinstance(token, dict):
                     # it's a path dictionary
@@ -981,13 +983,16 @@ class MRJobRunner(object):
                     # it's raw script
                     line += token
             writeln(line)
+        # redirect setup commands' input/output so they don't interfere
+        # with the task (see Issue #803).
+        writeln('} 0</dev/null 1>&2')
         writeln()
 
         writeln('# release exclusive file lock')
         writeln('exec 9>&-')
         writeln()
 
-        writeln('# run job from the original working directory')
+        writeln('# run task from the original working directory')
         writeln('cd $__mrjob_PWD')
         writeln('"$@"')
 
@@ -1012,8 +1017,7 @@ class MRJobRunner(object):
 
                 self._stdin_path = stdin_path
 
-        return [self._stdin_path if p == '-' else p
-                for p in self._input_paths]
+        return [self._stdin_path if p == '-' else p for p in self._input_paths]
 
     def _create_mrjob_tar_gz(self):
         """Make a tarball of the mrjob library, without .pyc or .pyo files,
